@@ -4,8 +4,8 @@
  * Author          : Ulrich Pfeifer
  * Created On      : Wed May 11 09:30:19 1994
  * Last Modified By: Ulrich Pfeifer
- * Last Modified On: Sun Sep 10 10:47:23 1995
- * Update Count    : 24
+ * Last Modified On: Mon Jan 27 22:14:27 1997
+ * Update Count    : 36
  * Status          : Unknown, Use with caution!
  */
 
@@ -43,7 +43,7 @@
 /*
  * Length of the headers
  */
-#define MAX_HEADER_LEN 100
+#define MAX_HEADER_LEN 500
 
 #define MAX_AUTHOR_LEN 25
 #define MAX_DATE_LEN 4
@@ -51,7 +51,7 @@
 #define MAX_TYPE_LEN 20
 #define ANSI_DATE_LENGTH 6 /* YYMMDD */
 
-#define MAX_HEADLINE_LEN 300
+#define MAX_HEADLINE_LEN 600
 
 /*
  * these are needed for linking freeWAIS-sf with perl
@@ -65,3 +65,6 @@
 
 /* #define MYREGEXP /**/
 /* #define MYCTYPE /**/
+#define HAS_GRUNDFORM
+#define SPRINGER
+#define HTML_ENTITIES
