@@ -1,6 +1,6 @@
 /*                               -*- Mode: C -*- 
  * $Basename: wutil.c $
- * $Revision: 1.4.1.5.1.3 $
+ * $Revision: 1.4.1.5.1.4 $
  * Author          : Brewser Kahle, M. Tracy Shen
  * Created On      : 7/7/90
  * Last Modified By: Ulrich Pfeifer
@@ -14,7 +14,7 @@
  */
 
 #ifndef lint
-static char *PRCSid = "$Id: wutil.c 1.4.1.5.1.3 Mon, 05 May 1997 11:54:27 +0200 pfeifer $";
+static char *PRCSid = "$Id: wutil.c 1.4.1.5.1.4 Thu, 25 Feb 1999 09:46:46 +0100 goevert $";
 #endif
 
 /*  
@@ -152,7 +152,7 @@ char *itm_val;
 {
    
   printf("    %s (one line string):\n", itm_name);
-#ifdef _GETS__
+#ifndef _GETS__
   fgets( itm_val,255,stdin);
   if ( itm_val[0] == 0 )
     fgets(itm_val,255,stdin);
