@@ -1,91 +1,20 @@
 /*                               -*- Mode: C -*- 
- * wais-ui.c -- 
- * ITIID           : $ITI$ $Header $__Header$
- * Author          : Jonny Goldman?
+ * $Basename: wais-ui.c $
+ * $Revision: 1.4.1.9.1.3 $
+ * Author          : jonathan@Think.COM
  * Created On      : Thu Sep 14 16:05:48 1995
  * Last Modified By: Ulrich Pfeifer
- * Last Modified On: Fri Sep 29 11:34:20 1995
+ * Last Modified On: Mon May  5 10:09:24 1997
  * Language        : C
- * Update Count    : 5
+ * Update Count    : 7
  * Status          : Unknown, Use with caution!
  * 
- * (C) Copyright 1995, Universitt Dortmund, all rights reserved.
- */
-
-/* 
-   WIDE AREA INFORMATION SERVER SOFTWARE:
-   No guarantees or restrictions.  See the readme file for the full standard
-   disclaimer.
-
-   This is part of the shell user-interface tools for the WAIS software.
-   Do with it as you please.
-
-   jonathan@Think.COM
- */
-
-/* Copyright (c) CNIDR (see ../doc/CNIDR/COPYRIGHT) */
-
-/*
- * $Log: wais-ui.c,v $
- * Revision 2.0.1.3  1995/11/14 18:27:42  pfeifer
- * patch51:
- *
- * Revision 2.0.1.2  1995/09/29  11:18:27  pfeifer
- * patch17: Won't prepend source->directory if source->database starts
- * patch17: with '/'.
- *
- * Revision 2.0.1.1  1995/09/15  09:55:29  pfeifer
- * patch7: Fixed CNIDR copyright line.
- * patch7: Fix from kru@upc.muc.de (Frithjof Kruggel): -s option in
- * patch7: waisq, waissearch.
- *
- * Revision 2.0  1995/09/08  08:05:34  pfeifer
- * Metaconfig baseline
- *
- * Revision 1.3  1995/01/10  16:50:57  pfeifer
- * Fix from Jonny
- *
- * Revision 1.2  1994/08/05  07:30:21  pfeifer
- * Release beta 04
- *
- * Revision 1.31  93/06/23  20:02:23  warnock
- * Initial revision
- * 
- * Revision 1.24  92/06/03  17:19:20  jonathan
- * Reset signal handlers on use.  From mycroft@gnu.ai.mit.edu.
- * 
- * Revision 1.23  92/05/19  17:19:50  jonathan
- * Fixed bug where RetrieveWaisDocument failed to remove Seeker markup.
- * 
- * Revision 1.22  92/05/07  14:52:04  jonathan
- * Changed use of setitimer to alarm.  Thanks to
- * steinkel@carlisle-emh2.army.mil.
- * 
- * Revision 1.21  92/04/30  10:59:05  jonathan
- * Replace strdup with s_strdup.
- * 
- * Revision 1.20  92/04/02  14:21:59  jonathan
- * Copy type in all calls to makeDocObjUsing a generate_retrieval_apdu (which
- * calls makeDocObjUsing...).
- * 
- * Revision 1.19  92/04/01  17:19:35  jonathan
- * Fixed reporting of diagnostics when return text is empty.
- * 
- * Revision 1.18  92/03/17  14:33:17  jonathan
- * Renamed to wais-ui, cleaned up for use by X interface as well as shell
- * interfaces.
- * 
- * Revision 1.17  92/03/08  10:42:28  jonathan
- * Added one last loadSource in ViewWaisDocument.
- * 
- * Revision 1.16  92/03/06  14:50:13  jonathan
- * New and Improved source loading!
- * 
+ * (C) Copyright 1997, Universitt Dortmund, all rights reserved.
+ * (C) Copyright CNIDR (see ../doc/CNIDR/COPYRIGHT)
  */
 
 #ifndef lint
-static char    *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ui/RCS/wais-ui.c,v 2.0.1.3 1995/11/14 18:27:42 pfeifer Exp $";
-
+static char *PRCSid = "$Id: wais-ui.c 1.4.1.9.1.3 Mon, 05 May 1997 11:54:27 +0200 pfeifer $";
 #endif
 
 #define _C_QUESTION
