@@ -1,3 +1,18 @@
+/*                               -*- Mode: C -*- 
+ * $Basename: MyList.c $
+ * $Revision: 1.6.1.3 $
+ * Author          : XConsortium, borrowed by Jonny Goldman?
+ * Created On      : 91/09/27 18:35:07
+ * Last Modified By: Ulrich Pfeifer
+ * Last Modified On: Wed May  7 16:22:41 1997
+ * Language        : C
+ * Update Count    : 2
+ * Status          : Unknown, Use with caution!
+ * 
+ * (C) Copyright 1997, Universitt Dortmund, all rights reserved.
+ * (C) Copyright CNIDR (see ../doc/CNIDR/COPYRIGHT)
+ */
+
 /* Based on: */
 /* XConsortium: List.c,v 1.34 91/09/27 18:35:07 converse Exp */
 
@@ -23,13 +38,12 @@
  *
  */
 
-/* Copyright (c) CNIDR (see ../doc/CNIDR/COPYRIGHT) */
+#ifndef lint
+static char MyList_c_prcsid[] =
+  "$Id: MyList.c 1.6.1.3 Wed, 07 May 1997 18:04:42 +0200 pfeifer $";
+#endif
 
-
-static char MyList_c_rcsid[] =
-  "$Id: MyList.c,v 1.1.1.1 1996/06/04 20:38:32 julia Exp $";
-
-#include "../ir/cdialect.h"
+#include "cdialect.h"
 #include <stdio.h>
 
 #include <X11/IntrinsicP.h>
