@@ -1,116 +1,20 @@
-/* WIDE AREA INFORMATION SERVER SOFTWARE:
-   No guarantees or restrictions.  See the readme file for the full standard
-   disclaimer.
-
-   This is part of the X user-interface for the WAIS software.  Do with it
-   as you please.
-
-   jonathan@Think.COM
-*/
-
-/* Copyright (c) CNIDR (see ../doc/CNIDR/COPYRIGHT) */
-
-
-/* this file contains X specific code - it is an integral part of XWAIS */
-/* einet begin MAC */
-/* This was previously '#ifndef lint' */
-#ifdef RCSID    /* einet */
-/* einet end */
-static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/x/RCS/qcommands.c,v 2.0.1.1 1995/09/15 09:56:57 pfeifer Exp $";
-/*
- * was:
- * static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/x/RCS/qcommands.c,v 2.0.1.1 1995/09/15 09:56:57 pfeifer Exp $";
- *
- *
- * $Log: qcommands.c,v $
- * Revision 2.0.1.1  1995/09/15 09:56:57  pfeifer
- * patch7: Fixed CNIDR copyright line.
- *
- * Revision 2.0  1995/09/08  08:06:58  pfeifer
- * Metaconfig baseline
- *
- * Revision 1.8  1995/01/10  17:05:55  pfeifer
- * Bug wich causes coredump when submitting the same query more than once
- * No completely salvaged
- *
- * Revision 1.7  1994/11/24  10:04:45  pfeifer
- * XtMalloc for string was too short
- *
- * Revision 1.6  1994/08/05  07:25:53  pfeifer
- * Release beta 04
- *
- * Revision 1.5  1994/03/25  10:21:02  pfeifer
- * now will try to make 8-bit chars work
- *
- * Revision 1.4  93/07/19  16:32:27  warnock
- * Added catalog patches from Wayne Allen
+/*                               -*- Mode: C -*- 
+ * $Basename: qcommands.c $
+ * $Revision: 1.11.1.3 $
+ * Author          : jonathan@Think.COM
+ * Created On      : 92/02/17  12:55:38
+ * Last Modified By: Ulrich Pfeifer
+ * Last Modified On: Mon May  5 09:39:24 1997
+ * Language        : C
+ * Update Count    : 1
+ * Status          : Unknown, Use with caution!
  * 
- * Revision 1.5  93/07/18  warnock
- * Merged in Wayne Allen's mods for catalog widget, removed call to prep_retrieval
- *
- * Revision 1.4  1993/06/22  20:02:30  hardin
- * Plugged a MAJOR memory leak in SetupSearch.
- *
- * Revision 1.3  1993/01/08  21:31:22  wa
- * added call to prep_retrieval. This checks annoy and crash dates.
- *
- * Revision 1.2  1992/09/29  19:03:20  hardin
- * Changed "#ifndef lint" to "#ifdef RCSID"
- *
- * Revision 1.1  1992/09/23  10:09:22  wa
- * Initial revision
- *
- * Revision 1.28  92/06/22  13:58:29  jonathan
- * Added finish_search for loadSource failure in SetupSearch.
- *
- * Revision 1.27  92/06/22  10:51:44  jonathan
- * Removed references to myAsciiSink and myAsciiSrc.
- * Added function to return seed_words_used.
- *
- * Revision 1.26  92/06/15  13:54:46  jonathan
- * Lots of things.  Cleaned up a lot of the functions, moved things around.
- * Added stuff for Xt handling of IO.  No more alarms.
- *
- * Revision 1.25  92/06/03  17:09:50  jonathan
- * Modified calls to RebuildListWidget to position list widget appropriately.
- *
- * Revision 1.24  92/05/07  14:51:22  jonathan
- * Changed use of setitimer to alarm.  Thanks to
- * steinkel@carlisle-emh2.army.mil.
- *
- * Revision 1.23  92/04/30  12:22:11  jonathan
- * Modified to understand "quit no save" and desensitivize it when necessary.
- *
- * Revision 1.22  92/04/28  15:28:24  jonathan
- * Cleaned up use of scrollists.  Fixed bugs in double clicking.  Added
- * ability to view selected sources and relevant documents.
- *
- * Revision 1.21  92/03/23  16:08:43  jonathan
- * Added file requester, save as button, changed some sensitivity, that kind
- * of stuff.
- *
- * Revision 1.20  92/03/17  14:24:17  jonathan
- * Added Cursor code, timers, etc.  Really a lot of stuff.
- *
- * Revision 1.19  92/03/06  14:47:16  jonathan
- * New and Improved source loading!
- *
- * Revision 1.18  92/03/02  14:34:20  jonathan
- * Added -f to csh call, per blaze@think.com.
- *
- * Revision 1.17  92/03/01  14:02:08  jonathan
- * Modified all calls to PrintStatus to use PrintStatusW for compatibility
- * with ui PrintStatus.
- *
- * Revision 1.16  92/02/17  17:48:27  jonathan
- * Moved last_doc to a global, so it can be reset on a new search.
- *
- *
- * Revision 1.15  92/02/17  12:55:38  jonathan
- * Added WCAT type to text display.  Added RCSid and $Log too.
- *
- *
+ * (C) Copyright 1997, Universitt Dortmund, all rights reserved.
+ * (C) Copyright CNIDR (see ../doc/CNIDR/COPYRIGHT)
  */
+
+#ifndef lint
+static char *PRCSid = "$Id: qcommands.c 1.11.1.3 Mon, 05 May 1997 11:54:27 +0200 pfeifer $";
 #endif
 
 #define _C_QCOMMANDS
